@@ -1,11 +1,17 @@
+#!/usr/bin/python3
+
+# Test as "python -m schedules_tools.batches.schedule_batch"
+
+
+import argparse
 import logging
 import os
-
 from schedules_tools import SchedulesToolsException
 from schedules_tools import discovery
 from schedules_tools.discovery import search_paths
 from schedules_tools.models import Schedule
 from schedules_tools.storage_handlers import AcquireLockException
+import sys
 
 
 log = logging.getLogger(__name__)
@@ -343,7 +349,6 @@ def get_handlers_args_parser(add_help=False):
 
     For schedules tools scripts with handler arguments
     """
-    import argparse
 
     parser = argparse.ArgumentParser(add_help=add_help)
 
@@ -396,6 +401,8 @@ def get_handlers_args_parser(add_help=False):
 
     parser.add_argument('--html-title',
                         help='HTML export page title')
+    parser.add_argument('--html-table-footer',
+                        help='HTML export table footer')
     parser.add_argument('--html-table-header',
                         help='HTML export table header')
     parser.add_argument(
@@ -456,3 +463,43 @@ def get_handlers_args_parser(add_help=False):
                         type=sorting_field)
 
     return parser
+
+
+logger = logging.getLogger(__name__)
+
+
+def setup_logging(level):
+    log_format = '%(name)-10s %(levelname)7s: %(message)s'
+    sh = logging.StreamHandler(sys.stderr)
+    sh.setLevel(level)
+
+    formatter = logging.Formatter(log_format)
+    sh.setFormatter(formatter)
+
+    # setup root logger
+    inst = logging.getLogger('')
+    inst.setLevel(level)
+    inst.addHandler(sh)
+
+
+def main():
+    parser = argparse.ArgumentParser(description='Convert schedules source to target',
+                                     parents=[get_handlers_args_parser()])
+
+    parser.add_argument('source',
+                        help='Source handle (file/URL/...)',
+                        type=str,
+                        metavar='SRC')
+
+    parser.add_argument('target', metavar='TARGET',
+                        help='Output target', default='schedule.html', nargs='?')
+
+    args = parser.parse_args()
+
+    setup_logging(getattr(logging, args.log_level))
+
+    convert(args)
+
+
+if __name__ == '__main__':
+    main()
