@@ -1,9 +1,27 @@
+#!/usr/bin/python3
+
+"""
+Simple wrapper to get diff of two schedules
+
+It's able to show different attributes (by 'attrs' kwarg)
+and indicate missing phases
+
+Follows 'diff' exit codes:
+    0 - same
+    1 - different
+    2 - other trouble
+
+Test as "python -m schedules_tools.batches.diff"
+"""
+
+import argparse
 from datetime import datetime
 import json
 import logging
-
-from schedules_tools import jsondate
+from schedules_tools import jsondate, discovery
+from schedules_tools.converter import ScheduleConverter
 from schedules_tools.models import Task, Schedule
+import sys
 
 
 log = logging.getLogger(__name__)
@@ -75,7 +93,7 @@ def strings_similarity(str1, str2, winkler=True, scaling=0.1):
     m = float(num_of_matches)
     t = transpositions / 2.0
 
-    dj = (m/float(len1) + m/float(len2) + (m-t)/m) / 3.0
+    dj = (m / float(len1) + m / float(len2) + (m - t) / m) / 3.0
 
     if winkler:
         length = 0
@@ -447,3 +465,67 @@ class ScheduleDiff(object):
 
         kwargs['default'] = _encoder
         return json.dumps(self.result, **kwargs)
+
+
+def setup_logging(level):
+    log_format = '%(name)-10s %(levelname)7s: %(message)s'
+    sh = logging.StreamHandler(sys.stdout)
+    sh.setLevel(level)
+
+    formatter = logging.Formatter(log_format)
+    sh.setFormatter(formatter)
+
+    # setup root logger
+    inst = logging.getLogger('')
+    inst.setLevel(level)
+    inst.addHandler(sh)
+
+
+def main():
+    setup_logging(logging.INFO)
+    parser = argparse.ArgumentParser(
+        description='Tool to show differences between two schedules.')
+
+    parser.add_argument('--simple-diff',
+                        help='Simple comparison between two schedules.',
+                        action='store_true',
+                        default=False)
+
+    parser.add_argument(
+        '--handlers-path',
+        help='Add python-dot-notation path to discover handlers (needs to '
+             'be python module), can be called several times '
+             '(conflicting names will be overriden - the last '
+             'implementation will be used)',
+        action='append',
+        default=[])
+    parser.add_argument('--whole-days',
+                        help='Compare just date part of timestamp (will '
+                             'ignore differences in time)',
+                        action='store_true',
+                        default=False)
+    parser.add_argument('left')
+    parser.add_argument('right')
+    args = parser.parse_args()
+
+    for path in args.handlers_path:
+        discovery.search_paths.append(path)
+
+    left = ScheduleConverter()
+    left.import_schedule(args.left)
+
+    right = ScheduleConverter()
+    right.import_schedule(args.right)
+
+    if args.simple_diff:
+        diff_res = left.schedule.diff(right.schedule, whole_days=args.whole_days)
+    else:
+        diff_res = ScheduleDiff(left.schedule, right.schedule)
+
+    if diff_res:
+        print(diff_res)
+        sys.exit(1)
+
+
+if __name__ == '__main__':
+    main()
